MethodChannelCameraCutout class
- Inheritance
-
- Object
- PlatformInterface
- CameraCutoutPlatform
- MethodChannelCameraCutout
Constructors
Properties
-
changes
→ Stream<
CameraCutoutInfo> -
no setteroverride
- eventChannel → EventChannel
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getInfo(
) → Future< CameraCutoutInfo> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- eventChannelName → const String
- methodChannelName → const String