CameraCutoutGeometry class

Constructors

CameraCutoutGeometry({required Rect bounds, required CameraCutoutKind kind, required CameraCutoutAccuracy accuracy, CameraCutoutPath? path})
const
CameraCutoutGeometry.fromMap(Object? value)
factory

Properties

accuracy CameraCutoutAccuracy
final
bounds Rect
final
hashCode int
The hash code for this object.
no setterinherited
hasPath bool
no setter
kind CameraCutoutKind
final
path CameraCutoutPath?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited