CameraCutoutPathCommand class

Constructors

CameraCutoutPathCommand({required CameraCutoutPathOperation operation, Iterable<Offset> points = const <Offset>[]})
CameraCutoutPathCommand.fromMap(Object? value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
operation CameraCutoutPathOperation
final
points List<Offset>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addTo(Path path) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited